Crate double_ratchet_signal

Crate double_ratchet_signal 

Crate documentation provided in README.md

Modules

signal
The SignalDoubleRatchet provides an example of a secure implementation of the double_ratchet::CryptoProvider. This example code is based on the recommended cryptographic algorithms of the specification. I have not checked if the code is fully compatible with that of the Signal application but I suspect that it is.