Crate documentation provided in README.md
Modules
- signal
- The
SignalDoubleRatchetprovides an example of a secure implementation of thedouble_ratchet::CryptoProvider. This example code is based on the recommended cryptographic algorithms of the specification. I have not checked if the code is fully compatible with that of the Signal application but I suspect that it is.